@@ -1,5 +1,5 @@
 package Chemistry::Mol;
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 =head1 NAME
 
@@ -95,7 +95,6 @@ Add one or more Atom objects to the molecule. Returns the last atom added.
 
 sub add_atom {
     my $self = shift;
-
     for my $a (@_){
         push @{$self->{atoms}}, $a;
         $self->{byId}{$a->{id}} = $a;
@@ -125,7 +124,6 @@ Add one or more Bond objects to the molecule. Returns the last bond added.
 
 sub add_bond {
     my $self = shift;
-
     for my $b (@_){
         push @{$self->{bonds}}, $b;
 	$self->{byId}{$b->{id}} = $b;
@@ -146,6 +144,62 @@ sub new_bond {
     $self->add_bond(Chemistry::Bond->new(@_));
 }
 
+=item $mol->by_id($id)
+
+Return the atom or bond object with the corresponding id.
+
+=cut
+
+sub by_id {
+    my $self = shift;
+    my ($id) = @_;
+    $self->{byId}{$id};
+}
+
+=item $mol->atoms($n1, ...)
+
+Returns the atoms with the given indices, or all by default.
+
+=cut
+
+sub atoms {
+    my $self = shift;
+    if (@_) {
+        @{$self->{atoms}}[@_];
+    } else {
+        @{$self->{atoms}};
+    }
+}
+
+=item $mol->atoms_by_name($name)
+
+Returns the atoms with the given name (treated as an anchored regular
+expression).
+
+=cut
+
+sub atoms_by_name {
+    my $self = shift;
+    my $re = qr/^$_[0]$/;
+    my @ret = grep {$_->name =~ $re} $self->atoms;
+    wantarray ? @ret : @ret[0];
+}
+
+=item $mol->bonds($n1, ...)
+
+Returns the bonds with the given indices, or all by default.
+
+=cut
+
+sub bonds {
+    my $self = shift;
+    if (@_) {
+        @{$self->{bonds}}[@_];
+    } else {
+        @{$self->{bonds}};
+    }
+}
+
 =item $mol->print
 
 Convert the molecule to a string representation. 
@@ -257,7 +311,7 @@ sub register_type {
 
 =head1 SEE ALSO
 
-Chemistry::Atom, Chemistry::Bond, Chemistry::File
+L<Chemistry::Atom>, L<Chemistry::Bond>, L<Chemistry::File>
 
 =head1 AUTHOR
 
